@@ -195,15 +195,11 @@ sub call_api {
     $self->update_params_for_auth($header_params, $query_params, $auth_settings ); 
 
 
-    my $_url = $self->{config}{base_url}."/" . $resource_path;
+    my $_url = $self->{config}{base_url}."/" .$self->{config}{api_version} . $resource_path;
     if($get_token){
         $_url = $self->{config}{base_url} . $resource_path;
     }
 
-    # build header
-
-    $header_params->{'x-aspose-client'} = 'perl sdk';
-    $header_params->{'x-aspose-client-version'} = '25.6.1';  
     # build query 
     if (%$query_params) {
         $_url = ($_url . '?' . eval { URI::Query->new($query_params)->stringify });
@@ -256,10 +252,10 @@ sub call_api {
     elsif ($method eq 'DELETE') { #TODO support form data
         my $headers = HTTP::Headers->new(%$header_params);
         if($_body_data){
-            $_request = DELETE($_url, %$header_params, Content => $_body_data);
+            $_request = DELETE($_url, %$headers, Content => $_body_data);
         }
         else{
-            $_request = DELETE($_url, %$header_params);
+            $_request = DELETE($_url, %$headers);
         }
     }
     elsif ($method eq 'PATCH') { #TODO
@@ -267,9 +263,9 @@ sub call_api {
     else {
     }
     #proxy####################################################################
-    #$self->{ua}=LWP::UserAgent->new(ssl_opts => { verify_hostname => 0 },);
-    #$self->{ua}->proxy(['https'], "http://127.0.0.1:8888"); 
-    #printf $self->{ua}->ssl_opts;############################################
+    # $self->{ua}=LWP::UserAgent->new(ssl_opts => { verify_hostname => 0 },);
+    # $self->{ua}->proxy(['https'], "http://127.0.0.1:8888"); 
+    # printf $self->{ua}->ssl_opts;############################################
     $self->{ua}->timeout($self->{http_timeout} || $self->{config}{http_timeout});
     $self->{ua}->agent($self->{http_user_agent} || $self->{config}{http_user_agent});
 
