@@ -120,7 +120,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => 'Class summary: The features of the new smartphone include a high-resolution display, multiple camera lenses for versatile photography, a fast processor for seamless performance, and a larger battery for extended usage time.',
+__PACKAGE__->class_documentation({description => '',
                                   class => 'ConvertTextOptions',
                                   required => [], # TODO
 }                                 );
@@ -130,7 +130,7 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'Name',
-     	description => 'The class has a public property called "Name" of type string that can be accessed and modified.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
