@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => 'Class summary: This class covers various features related to data visualization and graphical representation of data sets.',
+__PACKAGE__->class_documentation({description => '',
                                   class => 'FormulaFormatCondition',
                                   required => [], # TODO
 }                                 );
