@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2024 Aspose.Cells Cloud
+Copyright (c) 2025 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -353,14 +353,14 @@ __PACKAGE__->method_documentation({
      'hidden_col_display_type' => {
      	datatype => 'string',
      	base_name => 'HiddenColDisplayType',
-     	description => 'Hidden column(the width of this column is 0) in excel,before save this into                html format, if HtmlHiddenColDisplayType is "Remove",the hidden column would               ont been output, if the value is "Hidden", the column would been output,but was hidden,the default value is "Hidden"',
+     	description => 'Hidden column(the width of this column is 0) in excel,before save this into               html format, if HtmlHiddenColDisplayType is "Remove",the hidden column would               ont been output, if the value is "Hidden", the column would been output,but was hidden,the default value is "Hidden"',
      	format => '',
      	read_only => '',
      		},
      'hidden_row_display_type' => {
      	datatype => 'string',
      	base_name => 'HiddenRowDisplayType',
-     	description => 'Hidden row(the height of this row is 0) in excel,before save this into html                format, if HtmlHiddenRowDisplayType is "Remove",the hidden row would ont               been output, if the value is "Hidden", the row would been output,but was               hidden,the default value is "Hidden"',
+     	description => 'Hidden row(the height of this row is 0) in excel,before save this into html               format, if HtmlHiddenRowDisplayType is "Remove",the hidden row would ont               been output, if the value is "Hidden", the row would been output,but was               hidden,the default value is "Hidden"',
      	format => '',
      	read_only => '',
      		},
@@ -392,6 +392,13 @@ __PACKAGE__->method_documentation({
      	format => '',
      	read_only => '',
      		},
+     'cell_name_attribute' => {
+     	datatype => 'string',
+     	base_name => 'CellNameAttribute',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
      'save_format' => {
      	datatype => 'string',
      	base_name => 'SaveFormat',
@@ -489,6 +496,7 @@ __PACKAGE__->swagger_types( {
     'is_exp_image_to_temp_dir' => 'boolean',
     'page_title' => 'string',
     'parse_html_tag_in_cell' => 'boolean',
+    'cell_name_attribute' => 'string',
     'save_format' => 'string',
     'cached_file_folder' => 'string',
     'clear_data' => 'boolean',
@@ -538,6 +546,7 @@ __PACKAGE__->attribute_map( {
     'is_exp_image_to_temp_dir' => 'IsExpImageToTempDir',
     'page_title' => 'PageTitle',
     'parse_html_tag_in_cell' => 'ParseHtmlTagInCell',
+    'cell_name_attribute' => 'CellNameAttribute',
     'save_format' => 'SaveFormat',
     'cached_file_folder' => 'CachedFileFolder',
     'clear_data' => 'ClearData',
