@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2024 Aspose.Cells Cloud
+Copyright (c) 2025 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -118,13 +118,20 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => '           Represents the top 10 filter.           ',
                                   class => 'Top10Filter',
                                   required => [], # TODO
 }                                 );
 
 
 __PACKAGE__->method_documentation({
+     'field_index' => {
+     	datatype => 'int',
+     	base_name => 'FieldIndex',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
      'criteria' => {
      	datatype => 'string',
      	base_name => 'Criteria',
@@ -156,6 +163,7 @@ __PACKAGE__->method_documentation({
 });
 
 __PACKAGE__->swagger_types( {
+    'field_index' => 'int',
     'criteria' => 'string',
     'is_percent' => 'boolean',
     'is_top' => 'boolean',
@@ -163,6 +171,7 @@ __PACKAGE__->swagger_types( {
 } );
 
 __PACKAGE__->attribute_map( {
+    'field_index' => 'FieldIndex',
     'criteria' => 'Criteria',
     'is_percent' => 'IsPercent',
     'is_top' => 'IsTop',
