@@ -35,7 +35,6 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -71,7 +70,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_add_text_content' } = { 
-    	summary => 'Adds text content to a workbook at specified positions within cells based on provided options using ASP.NET Core Web API.',
+    	summary => '',
         params => $params,
         returns => 'FileInfo',
     };
@@ -83,7 +82,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = 'v3.0/cells/addtext';
+    my $_resource_path = '/cells/addtext';
 
     my $_method = 'POST';
     my $query_params = {};
@@ -100,14 +99,11 @@ sub run_http_request {
  
     my $_body_data;
 
-
     # body params
     if (defined $self->add_text_options) {
+        #$_body_data = $self->add_text_options;
          $_body_data = JSON->new->convert_blessed->encode( $self->add_text_options);
     }
-
- 
-
     # authentication setting, if any
     my $auth_settings = [qw()];
 
