@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2024 Aspose.Cells Cloud
+Copyright (c) 2025 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -61,10 +61,10 @@ sub new {
 # Run Operation Request
 # PostAssembleRequest.File : File to upload  ,
 # PostAssembleRequest.datasource :   ,
-# PostAssembleRequest.outFormat : The format to convert(CSV/XLS/HTML/MHTML/ODS/PDF/XML/TXT/TIFF/XLSB/XLSM/XLSX/XLTM/XLTX/XPS/PNG/JPG/JPEG/GIF/EMF/BMP/MD[Markdown]/Numbers)  ,
-# PostAssembleRequest.password : The password needed to open an Excel file.  ,
-# PostAssembleRequest.checkExcelRestriction : Whether check restriction of excel file when user modify cells related objects.  ,
-# PostAssembleRequest.region : The regional settings for workbook.   
+# PostAssembleRequest.outFormat :   ,
+# PostAssembleRequest.password :   ,
+# PostAssembleRequest.checkExcelRestriction :   ,
+# PostAssembleRequest.region :    
 
 {
     my $params = {
@@ -75,7 +75,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_assemble' } = { 
-    	summary => 'Assemble data files with template files to generate files in various formats.',
+    	summary => '',
         params => $params,
         returns => 'FilesResult',
     };
@@ -157,28 +157,28 @@ __PACKAGE__->method_documentation({
      'out_format' => {
      	datatype => 'string',
      	base_name => 'outFormat',
-     	description => 'The format to convert(CSV/XLS/HTML/MHTML/ODS/PDF/XML/TXT/TIFF/XLSB/XLSM/XLSX/XLTM/XLTX/XPS/PNG/JPG/JPEG/GIF/EMF/BMP/MD[Markdown]/Numbers)',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'password' => {
      	datatype => 'string',
      	base_name => 'password',
-     	description => 'The password needed to open an Excel file.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'check_excel_restriction' => {
      	datatype => 'string',
      	base_name => 'checkExcelRestriction',
-     	description => 'Whether check restriction of excel file when user modify cells related objects.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'region' => {
      	datatype => 'string',
      	base_name => 'region',
-     	description => 'The regional settings for workbook.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},    
