@@ -35,7 +35,6 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -63,8 +62,7 @@ sub new {
 # PostConvertWorkbookToMarkdownRequest.File : File to upload  ,
 # PostConvertWorkbookToMarkdownRequest.password : The password needed to open an Excel file.  ,
 # PostConvertWorkbookToMarkdownRequest.checkExcelRestriction : Whether check restriction of excel file when user modify cells related objects.  ,
-# PostConvertWorkbookToMarkdownRequest.region : The regional settings for workbook.  ,
-# PostConvertWorkbookToMarkdownRequest.FontsLocation : Use Custom fonts.   
+# PostConvertWorkbookToMarkdownRequest.region : The regional settings for workbook.   
 
 {
     my $params = {
@@ -87,7 +85,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = 'v3.0/cells/convert/markdown';
+    my $_resource_path = '/cells/convert/markdown';
 
     my $_method = 'POST';
     my $query_params = {};
@@ -111,21 +109,16 @@ sub run_http_request {
 
     if(defined $self->region){
         $query_params->{'region'} = $client->to_query_value($self->region);      
-    }
-
-    if(defined $self->fonts_location){
-        $query_params->{'FontsLocation'} = $client->to_query_value($self->fonts_location);      
     } 
     my $_body_data;
-
+ 
 
     if (defined $self->file) {   
         my $map_file = $self->file;
         while ( my ($filename,$value) = each( %$map_file ) ) {
                 $form_params->{$filename} = [$value ,$filename,'application/octet-stream'];
         }
-    }
- 
+    } 
 
     # authentication setting, if any
     my $auth_settings = [qw()];
@@ -163,13 +156,6 @@ __PACKAGE__->method_documentation({
      	base_name => 'region',
      	description => 'The regional settings for workbook.',
      	format => '',
-     	read_only => '',
-     		},
-     'fonts_location' => {
-     	datatype => 'string',
-     	base_name => 'FontsLocation',
-     	description => 'Use Custom fonts.',
-     	format => '',
      	read_only => '',
      		},    
 });
@@ -179,8 +165,7 @@ __PACKAGE__->attribute_map( {
     'file' => 'File',
     'password' => 'password',
     'check_excel_restriction' => 'checkExcelRestriction',
-    'region' => 'region',
-    'fonts_location' => 'FontsLocation' 
+    'region' => 'region' 
 } );
 
 __PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});
