@@ -35,7 +35,6 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -88,7 +87,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = 'v3.0/cells/rotate';
+    my $_resource_path = '/cells/rotate';
 
     my $_method = 'POST';
     my $query_params = {};
@@ -122,15 +121,14 @@ sub run_http_request {
         $query_params->{'region'} = $client->to_query_value($self->region);      
     } 
     my $_body_data;
-
+ 
 
     if (defined $self->file) {   
         my $map_file = $self->file;
         while ( my ($filename,$value) = each( %$map_file ) ) {
                 $form_params->{$filename} = [$value ,$filename,'application/octet-stream'];
         }
-    }
- 
+    } 
 
     # authentication setting, if any
     my $auth_settings = [qw()];
